Using the methodology generated by Muoko et. al (see README for
full citation), run the modelling with the JAGS sampler. This
function accepts a number of different arguments, but defaulted
arguments are assumed to be best for most systems. Obviously,
if there is prior knowledge, this can be adjusted at the user's
own discretion.